from setuptools import setup, find_packages

VERSION = '0.0.2'
DESCRIPTION = 'A simple password manager'
LONG_DESCRIPTION = """
# Simple Password Manager

## Overview
Simple Password Manager is a lightweight and secure Python package for managing passwords. It allows users to store, retrieve, and manage their passwords securely using encryption. It supports two types of storage: local storage and cloud storage. The package provides a command-line interface (CLI) for easy management of passwords.

## Features
- **Encryption:** All passwords are encrypted using a master password.
- **Secure Storage:** Passwords are stored in a secure format locally or in the cloud.
- **Command-Line Interface:** Easy to use CLI for managing passwords.
- **Custom Password Generation:** Generate secure passwords on the fly.
- **Log and Backup System:** Keeps track of changes and allows for easy backup.

## Installation
Install the package using pip:
```bash
pip install simple-password-manager
"""

setup(
    name="simple-password-manager",
    version=VERSION,
    author="Amir Mallek",
    author_email="mallekamir123@gmail.com",
    url="https://github.com/7alle9/Simple-Password-Manager",
    description=DESCRIPTION,
    long_description=LONG_DESCRIPTION,
    long_description_content_type='text/markdown',
    packages=find_packages(),
    install_requires=[
        'cryptography',
        'requests',
        'platformdirs',
        'pyperclip'
    ],
    entry_points={
        'console_scripts': [
            'spm=simplepasswordmanager.cli:main',
        ],
    },
    keywords=['python', 'password', 'manager', 'simple', 'cli', 'security'],
    classifiers=[
        "Development Status :: 4 - Beta",
        "Intended Audience :: Developers",
        "Intended Audience :: End Users/Desktop",
        "Topic :: Security :: Cryptography",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Operating System :: OS Independent"
    ]
)
